==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/product/OIngredientSku.java <==
package eleme.openapi.sdk.api.entity.product;

import eleme.openapi.sdk.api.enumeration.product.*;
import eleme.openapi.sdk.api.entity.product.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class OIngredientSku{

    /**
     * 配料的skuId
     */
    private Long skuId;
    public Long getSkuId() {
        return skuId;
    }
    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }
    
    /**
     * 配料是否必选
     */
    private Boolean required;
    public Boolean getRequired() {
        return required;
    }
    public void setRequired(Boolean required) {
        this.required = required;
    }
    
    /**
     * 选中状态
     */
    private boolean selected;
    public boolean getSelected() {
        return selected;
    }
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
    
    /**
     * 最少选择个数
     */
    private Integer minSelectNum;
    public Integer getMinSelectNum() {
        return minSelectNum;
    }
    public void setMinSelectNum(Integer minSelectNum) {
        this.minSelectNum = minSelectNum;
    }
    
    /**
     * 最多选择个数
     */
    private Integer maxSelectNum;
    public Integer getMaxSelectNum() {
        return maxSelectNum;
    }
    public void setMaxSelectNum(Integer maxSelectNum) {
        this.maxSelectNum = maxSelectNum;
    }
    
    /**
     * 默认选中数量
     */
    private Integer defaultSelectNum;
    public Integer getDefaultSelectNum() {
        return defaultSelectNum;
    }
    public void setDefaultSelectNum(Integer defaultSelectNum) {
        this.defaultSelectNum = defaultSelectNum;
    }
    
    /**
     * 自定义定价
     */
    private OPriceInfo customPriceInfo;
    public OPriceInfo getCustomPriceInfo() {
        return customPriceInfo;
    }
    public void setCustomPriceInfo(OPriceInfo customPriceInfo) {
        this.customPriceInfo = customPriceInfo;
    }
    
    /**
     * 份数
     */
    private Integer quantity;
    public Integer getQuantity() {
        return quantity;
    }
    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/product/OIngredientSku.java <==
package eleme.openapi.sdk.api.entity.product;

import eleme.openapi.sdk.api.enumeration.product.*;
import eleme.openapi.sdk.api.entity.product.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class OIngredientSku{

    /**
     * 配料的skuId
     */
    private Long skuId;
    public Long getSkuId() {
        return skuId;
    }
    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }
    
    /**
     * 配料是否必选
     */
    private Boolean required;
    public Boolean getRequired() {
        return required;
    }
    public void setRequired(Boolean required) {
        this.required = required;
    }
    
    /**
     * 上下架状态
     */
    private Integer saleStatus;
    public Integer getSaleStatus() {
        return saleStatus;
    }
    public void setSaleStatus(Integer saleStatus) {
        this.saleStatus = saleStatus;
    }
    
    /**
     * 选中状态
     */
    private boolean selected;
    public boolean getSelected() {
        return selected;
    }
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
    
    /**
     * 最少选择个数
     */
    private Integer minSelectNum;
    public Integer getMinSelectNum() {
        return minSelectNum;
    }
    public void setMinSelectNum(Integer minSelectNum) {
        this.minSelectNum = minSelectNum;
    }
    
    /**
     * 最多选择个数
     */
    private Integer maxSelectNum;
    public Integer getMaxSelectNum() {
        return maxSelectNum;
    }
    public void setMaxSelectNum(Integer maxSelectNum) {
        this.maxSelectNum = maxSelectNum;
    }
    
    /**
     * 默认选中数量
     */
    private Integer defaultSelectNum;
    public Integer getDefaultSelectNum() {
        return defaultSelectNum;
    }
    public void setDefaultSelectNum(Integer defaultSelectNum) {
        this.defaultSelectNum = defaultSelectNum;
    }
    
    /**
     * 自定义定价
     */
    private OPriceInfo customPriceInfo;
    public OPriceInfo getCustomPriceInfo() {
        return customPriceInfo;
    }
    public void setCustomPriceInfo(OPriceInfo customPriceInfo) {
        this.customPriceInfo = customPriceInfo;
    }
    
    /**
     * 份数
     */
    private Integer quantity;
    public Integer getQuantity() {
        return quantity;
    }
    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    
}
